@@ -14,6 +14,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
+
 from rat import Rat
 import mfutils
 from const import DEFAULT_VELOCITY, DEFAULT_VOLUME
@@ -205,7 +207,7 @@ class MidiEventStream(object):
                         if e.m_pitch not in track_notes[idx]:
                             # This could happen if the user adds extra NoteOffEvents or adds one
                             # with the wrong pitch.
-                            print "info: not stopping, not playing now:", e
+                            logging.debug("not stopping, not playing now: %s" % e)
                             continue
                         patch = track_notes[idx][e.m_pitch]
                         del track_notes[idx][e.m_pitch]
@@ -226,7 +228,7 @@ class MidiEventStream(object):
                         elif isinstance(e, TempoEvent):
                             tempo_request = e
                         else:
-                            print "NOT HANDLING EVENT:", e
+                            logging.debug("MidiEventStream: NOT HANDLING EVENT: %s" % e)
             for idx, track in enumerate(tracks2):
                 if tpos in track:
                     for e in track[tpos]['NoteOnEvents']:
@@ -255,7 +257,7 @@ class MidiEventStream(object):
                                 ch_dev.set_channel_data(chn, 'volume', track_state[idx]['volume-requested'])
                                 yield self.VOLUME, chn, track_state[idx]['volume-requested']
                         if ch_dev.is_playing(chn, e.m_pitch):
-                            print "info: ignoring duplicate tone:", e
+                            logging.debug("MidiEventStream: ignoring duplicate tone: %s" % e)
                             continue
                         track_notes[idx][e.m_pitch] = track_state[idx]['patch-requested']
                         # ch_dev must know which tones are sounding on which
@@ -290,7 +292,7 @@ class MidiEventStream(object):
                 elif e[0] == self.VOLUME:
                     v = v + mfutils.mf_volume_change(e[1], e[2])
                 elif e[0] == self.BENDER:
-                    print "FIXME todo: seq_bender for play_with_drvmidi"
+                    logging.debug("create_midifile: FIXME todo: seq_bender for play_with_drvmidi")
                     #m.seq_bender(DEV, e[1], e[2])
                 else:
                     raise Exception("mpd.track: Corrupt track error")
