@@ -56,7 +56,13 @@ class ExecutableFormatStringException(OsUtilsException):
 class BinaryBaseException(OsUtilsException):
     def __init__(self, binary, exception):
         OsUtilsException.__init__(self)
-        self.msg2 = _("Tried `%(bin)s`:\n\n\t%(exception)s\n\nPlease check that the program is installed. If you did not supply the full path to the program in the preferences window (Ctrl-12), you must make sure the program is on your PATH.") % {'bin': binary, 'exception': exception}
+        self.msg2 = _("Tried `%(bin)s`:\n\n\t%(exception)s\n\n"
+            "Please check that the program is installed. If you did not supply"
+            "the full path to the program in the preferences window (Ctrl-12),"
+            "you must make sure the program is on your PATH.") % {
+             'bin': str(binary).decode(sys.getfilesystemencoding(), 'replace'),
+             'exception': str(exception).decode(
+                 sys.getfilesystemencoding(), 'replace')}
 
 class BinaryForProgramException(BinaryBaseException):
     def __init__(self, program_name, binary, exception):
